
# Spectator for Python

> :warning: Experimental

This is a Python port of the [Spectator] library for Java. Currently this is an experiment
to help determine the level of effort to support another language.

[Spectator]: https://github.com/Netflix/spectator/
